@@ -192,6 +192,9 @@ impl PositionedChunk {
 
         let mut chunk_bounds: Option<Rect> = None;
 
+        // Find the bounding box of the entire chunk by taking the union of the bounding boxes
+        // of each individual span.
+
         for mspan in &measured.spans {
             let params = NormalizeParams::new(&mspan.values, &layout_context.viewport);
 
@@ -223,6 +226,8 @@ impl PositionedChunk {
             let span_bounds =
                 Rect::from_size(layout_size.0, layout_size.1).translate(rendered_position);
 
+            // We take the union here
+
             if let Some(bounds) = chunk_bounds {
                 chunk_bounds = Some(bounds.union(&span_bounds));
             } else {
@@ -761,22 +766,24 @@ impl ElementTrait for Text {
         }
     }
 
-    fn draw(
+    fn layout(
         &self,
         node: &Node,
         acquired_nodes: &mut AcquiredNodes<'_>,
         cascaded: &CascadedValues<'_>,
         viewport: &Viewport,
         draw_ctx: &mut DrawingCtx,
-        clipping: bool,
-    ) -> Result<BoundingBox, InternalRenderingError> {
+        _clipping: bool,
+    ) -> Result<Option<Layer>, InternalRenderingError> {
         let values = cascaded.get();
         let params = NormalizeParams::new(values, viewport);
 
         let elt = node.borrow_element();
 
+        let session = draw_ctx.session().clone();
+
         let stacking_ctx = StackingContext::new(
-            draw_ctx.session(),
+            &session,
             acquired_nodes,
             &elt,
             values.transform(),
@@ -785,14 +792,14 @@ impl ElementTrait for Text {
         );
 
         let layout_text = {
-            let transform = draw_ctx.get_transform_for_stacking_ctx(&stacking_ctx, clipping)?;
+            let transform = ValidTransform::try_from(Transform::identity()).unwrap();
 
             let layout_context = LayoutContext {
                 writing_mode: values.writing_mode(),
                 transform,
                 font_options: draw_ctx.get_font_options(),
                 viewport: viewport.clone(),
-                session: draw_ctx.session().clone(),
+                session: session.clone(),
             };
 
             let mut x = self.x.to_user(&params);
@@ -872,12 +879,25 @@ impl ElementTrait for Text {
             layout::Text { spans: text_spans }
         };
 
-        let layer = Layer {
+        Ok(Some(Layer {
             kind: LayerKind::Text(Box::new(layout_text)),
             stacking_ctx,
-        };
+        }))
+    }
 
-        draw_ctx.draw_layer(&layer, acquired_nodes, clipping, viewport)
+    fn draw(
+        &self,
+        node: &Node,
+        acquired_nodes: &mut AcquiredNodes<'_>,
+        cascaded: &CascadedValues<'_>,
+        viewport: &Viewport,
+        draw_ctx: &mut DrawingCtx,
+        clipping: bool,
+    ) -> Result<BoundingBox, InternalRenderingError> {
+        self.layout(node, acquired_nodes, cascaded, viewport, draw_ctx, clipping)
+            .and_then(|layer| {
+                draw_ctx.draw_layer(layer.as_ref().unwrap(), acquired_nodes, clipping, viewport)
+            })
     }
 }
 
